@@ -28,9 +28,6 @@
 
 . /etc/environ.sh
 
-ENVIRON_CONFIG_DIRS="${HOME}/.environ.d ${ENVIRON_CONFIG_DIRS}"
-export ENVIRON_CONFIG_DIRS
-
 if [ -e ${HOME}/.environ ]
 then
   for e in $(sed 's,[[:space:]]*#.*$,,' ${HOME}/.environ)
